@@ -133,6 +133,8 @@ class ModelISCore(GetMethodFieldMixin, ISCore):
 
     list_actions = ()
 
+    register_model = True
+
     # form params
     form_fields = None
     form_exclude = ()
@@ -406,7 +408,7 @@ class UIModelISCore(ModelISCore, UIISCore):
         if self.can_create and add_view:
             default_model_view_classes.append(('add', r'add/', add_view))
         if (self.can_read or self.can_update) and detail_view:
-            default_model_view_classes.append(('detail', r'(?P<pk>[-\w]+)/', detail_view))
+            default_model_view_classes.append(('detail', r'(?P<pk>[-\|\w]+)/', detail_view))
         if self.can_read and list_view:
             default_model_view_classes.append(('list', r'', list_view))
         return default_model_view_classes
