@@ -68,7 +68,7 @@ class ViewPattern(Pattern):
         return '%s:%s' % (self.site_name, self.name)
 
     def _get_try_kwargs(self, request, obj):
-        if obj and ('(?P<pk>[-\w]+)' in self.url_pattern or '(?P<pk>\d+)' in self.url_pattern):
+        if obj and ('(?P<pk>[-\|\w]+)' in self.url_pattern or '(?P<pk>\d+)' in self.url_pattern):
             return {'pk': obj.pk}
         return {}
 
@@ -177,9 +177,11 @@ class RESTPattern(ViewPattern):
         return self.resource_class.as_view(allowed_methods=self.methods)
 
     def get_allowed_methods(self, request, obj):
-        return self._call_view_method_with_request('check_permissions_and_get_allowed_methods', request,
-                                                   method_kwargs={'restricted_methods': self.methods, 'obj': obj},
-                                                   obj=obj)
+        return self._call_view_method_with_request(
+            'check_permissions_and_get_allowed_methods', request,
+            method_kwargs={'restricted_methods': self.methods, 'obj': obj},
+            obj=obj
+        )
 
 
 class HiddenPatternMixin:
@@ -213,7 +215,7 @@ class DoubleRESTPattern:
         result = OrderedDict()
         if detail_resource_methods:
             result['api-resource'] = self.pattern_class(
-                'api-resource-%s' % self.core.get_menu_group_pattern_name(), self.core.site_name, r'^(?P<pk>[-\w]+)/$',
+                'api-resource-%s' % self.core.get_menu_group_pattern_name(), self.core.site_name, r'^(?P<pk>[-\|\w]+)/$',
                 self.resource_class, self.core, detail_resource_methods, clone_view_class=False
             )
         if list_resource_methods:
